import React, { Component } from 'react';
import './App.css';
var _ = require('lodash');

/**
 * Result List Item
 */
const ResultItem = ({result}) => {
  return (
    <li className="result-item">
      <div className="title">
        {result.name}
      </div>
      <div className="subtitle">
        {result.gender} · {result.birth_year}
      </div>
    </li>
  ) 
}

/**
 * Results List
 */
const ResultsList = (props) => {
  const results = props.results.map( result => {
    return (
      <ResultItem 
        key={result.name}
        result={result}
      />
    )
  })
  return (
    <ul className="results-list">
      {results}
    </ul>
  ) 
}

/**
 * Search Bar Component
 */
class SearchBar extends React.Component {
  constructor(props) {
    super(props);

    this.state = { term: '' }
  }
  
  onInputChange(term) {
    this.setState({term});
    this.props.onSearchTermChange(term);
  }
  
  render() {
    return (
      <div className="input">
        <input
          onChange={event => this.onInputChange(event.target.value)} 
        />
      </div>
    )
  }
}

class App extends Component {
  constructor(props) {
    super(props)
    
    this.state = {
      error: null,
      isLoaded: false,
      items: []
    };
  }
  
  swapiSearch(term) {
    if (!term.length) {
      this.setState({
        isLoaded: true,
        items: []
      })
    } else {
      fetch(`https://swapi.co/api/people/?search=${term}`)
      .then(res => res.json())
      .then( res => {
          this.setState({
            isLoaded: true,
            items: res.results
          });
        },
        (error) => {
          this.setState({
            isLoaded: true,
            error
          });
        }
      )
    }
  }
  
  render() {
    const search = _.debounce(term => {this.swapiSearch(term)}, 300)
    return (
      <div>
        <SearchBar onSearchTermChange={search}/>
        <ResultsList results={this.state.items} />
      </div>
    );
  }
}

export default App;
